# PersiaML server

[![Rust](https://github.com/PersiaML/PersiaML-server/actions/workflows/rust.yml/badge.svg)](https://github.com/PersiaML/PersiaML-server/actions/workflows/rust.yml)  [![PyPI version](https://badge.fury.io/py/persia-core.svg)](https://badge.fury.io/py/persia-core) [![GitHub license](https://img.shields.io/github/license/PersiaML/PersiaML-server)](https://github.com/PersiaML/PersiaML-server/blob/master/LICENSE)

PersiaML server part.
